@@ -2,13 +2,14 @@ package main
 
 import "time"
 
-type newSnapFunc func(int64, *Snapshot, chan<-struct{}) *Snapshot
+type newSnapFunc func(int64, *Snapshot, chan<- struct{}) *Snapshot
 
 func ClockSnapshot(begin int64, newSnap newSnapFunc, interval time.Duration) <-chan *Snapshot {
 	c := make(chan *Snapshot)
 
 	go func() {
 		var s *Snapshot
+
 		t := time.Tick(interval)
 
 		for now := range t {
@@ -22,11 +23,12 @@ func ClockSnapshot(begin int64, newSnap newSnapFunc, interval time.Duration) <-c
 	return c
 }
 
-func PreciseSnapshot(begin int64, newSnap newSnapFunc, interval time.Duration) <-chan *Snapshot {
+func PreciseSnapshot(newSnap newSnapFunc, interval time.Duration) <-chan *Snapshot {
 	c := make(chan *Snapshot)
 
 	go func() {
 		var s *Snapshot
+
 		begin := time.Now().UnixNano()
 
 		for {
@@ -35,8 +37,11 @@ func PreciseSnapshot(begin int64, newSnap newSnapFunc, interval time.Duration) <
 			id := (start.UnixNano() - begin) / int64(time.Millisecond)
 			ns := newSnap(id, s, finish)
 			s = ns
+
 			c <- ns
+
 			<-finish
+
 			pTime := time.Since(start)
 
 			if pTime > interval {
@@ -50,11 +55,12 @@ func PreciseSnapshot(begin int64, newSnap newSnapFunc, interval time.Duration) <
 	return c
 }
 
-func SequentialSnapshot(begin int64, newSnap newSnapFunc, interval time.Duration) <-chan *Snapshot {
+func SequentialSnapshot(newSnap newSnapFunc, interval time.Duration) <-chan *Snapshot {
 	c := make(chan *Snapshot)
 
 	go func() {
 		var s *Snapshot
+
 		begin := time.Now().UnixNano()
 
 		for {
@@ -62,6 +68,7 @@ func SequentialSnapshot(begin int64, newSnap newSnapFunc, interval time.Duration
 			id := (time.Now().UnixNano() - begin) / int64(time.Millisecond)
 			s = newSnap(id, s, finish)
 			c <- s
+
 			<-finish
 
 			time.Sleep(interval)
