@@ -412,7 +412,7 @@ func (v *Viddy) arrange() {
 }
 
 // Run is entry point to run viddy.
-//nolint: funlen,gocognit,cyclop
+// nolint: funlen,gocognit,cyclop
 func (v *Viddy) Run() error {
 	b := tview.NewTextView()
 	b.SetDynamicColors(true)
@@ -553,11 +553,27 @@ func (v *Viddy) Run() error {
 			any = true
 		}
 
-		if event.Key() == tcell.KeyEsc || event.Rune() == 'q' {
+		if event.Key() == tcell.KeyEsc {
 			v.showHelpView = false
 			v.arrange()
 		}
 
+		if event.Rune() == 'q' {
+			if v.showHelpView { // if it's help mode, just go back
+				v.showHelpView = false
+				v.arrange()
+			} else { // it's not help view, so just quit
+				v.app.Stop()
+				os.Exit(0)
+			}
+		}
+
+		// quit viddy from any view
+		if event.Rune() == 'Q' {
+			v.app.Stop()
+			os.Exit(0)
+		}
+
 		switch event.Rune() {
 		case 's':
 			v.isSuspend = !v.isSuspend
@@ -567,6 +583,9 @@ func (v *Viddy) Run() error {
 			v.SetIsShowDiff(!v.isShowDiff)
 		case 't':
 			v.SetIsNoTitle(!v.isNoTitle)
+		case 'u':
+			b.SetWrap(v.unfold)
+			v.unfold = !v.unfold
 		case 'x':
 			if v.isDebug {
 				v.ShowLogView(!v.showLogView)
@@ -597,8 +616,6 @@ func (v *Viddy) Run() error {
 
 	v.UpdateStatusView()
 
-	app.EnableMouse(true)
-
 	v.app = app
 	v.arrange()
 
@@ -681,7 +698,7 @@ func (v *Viddy) goToOldestOnTimeMachine() {
 	}
 }
 
-var helpTemplate = `Press ESC or Q to go back
+var helpTemplate = `Press ESC or q to go back
 
  [::b]Key Bindings[-:-:-]
 
@@ -693,6 +710,8 @@ var helpTemplate = `Press ESC or Q to go back
    Toggle diff               : [yellow]d[-:-:-]
    Toggle header display     : [yellow]t[-:-:-]
    Toggle help view          : [yellow]?[-:-:-]
+   Toggle unfold             : [yellow]u[-:-:-]
+   Quit Viddy                : [yellow]Q[-:-:-]
 
    [::u]Pager[-:-:-]
 
